@@ -96,7 +96,7 @@ co="--enable-shared"
 ./test.sh basic.sh $src_dir -co: $co -mo: $mo
 ./renametest.sh basic $output_dir/basic--enable-shared
 
-co="--enable-debug --with-extra-CFLAGS=\\'-Wstrict-prototypes\\'"
+co="--enable-debug --with-extra-CFLAGS=\\'-Wstrict-prototypes -Wno-deprecated\\'"
 ./test.sh basic.sh $src_dir -co: $co -mo: $mo -eo: $eo
 ./renametest.sh basic $output_dir/basic-debug1
 
@@ -104,7 +104,7 @@ co="--enable-maxdim=4 --enable-debug"
 ./test.sh basic.sh $src_dir -co: $co -mo: $mo -eo: -maxdim
 ./renametest.sh basic $output_dir/basic--enable-maxdim=4
 
-co="--enable-complex --enable-maxdim=4 --enable-debug"
+co="--enable-complex --enable-maxdim=4 --enable-debug --with-extra-CFLAGS='-Wno-incompatible-pointer-types'"
 ./test.sh basic.sh $src_dir -co: $co -mo: $mo -eo: -complex
 # ignore complex compiler output for now
 rm -fr basic.dir/make.???
@@ -130,7 +130,7 @@ co="--enable-longdouble --enable-debug"
 ./test.sh basic.sh $src_dir -co: $co -mo: $mo -ro: -longdouble
 ./renametest.sh basic $output_dir/basic--enable-longdouble
 
-co="--enable-debug CC=mpiCC"
+co="--enable-debug CC=mpiCC --with-extra-CFLAGS=\\'-Wno-deprecated\\'"
 ./test.sh basic.sh $src_dir -co: $co -mo: $mo -ro: $ro -eo: $eo
 ./renametest.sh basic $output_dir/basic-debug-cpp
 
@@ -142,6 +142,10 @@ co="--enable-debug --enable-mixed-precision"
 ./test.sh basic.sh $src_dir -co: $co -mo: $mo -ro: $ro
 ./renametest.sh basic $output_dir/basic--mixed-precision
 
+co="--enable-debug --enable-mixed-precision --enable-shared"
+./test.sh basic.sh $src_dir -co: $co -mo: $mo
+./renametest.sh basic $output_dir/basic--mixed-precision-shared
+
 co="--enable-mixedint --enable-debug"
 RO="-ams -ij-mixed -sstruct-mixed -struct -lobpcg-mixed"
 ./test.sh basic.sh $src_dir -co: $co -mo: $mo -ro: $RO
@@ -189,6 +193,10 @@ co="-DCMAKE_BUILD_TYPE=Debug -DHYPRE_ENABLE_MIXED_PRECISION=ON"
 ./test.sh cmake.sh $root_dir -co: $co -mo: $mo
 ./renametest.sh cmake $output_dir/cmake-mixed-precision
 
+co="-DCMAKE_BUILD_TYPE=Debug -DHYPRE_ENABLE_MIXED_PRECISION=ON -DBUILD_SHARED_LIBS=ON"
+./test.sh cmake.sh $root_dir -co: $co -mo: $mo
+./renametest.sh cmake $output_dir/cmake-mixed-precision-shared
+
 # cmake build doesn't currently support maxdim
 # cmake build doesn't currently support complex
 
