@@ -29,8 +29,6 @@
 
 #include "../../parcsr_ls/HYPRE_parcsr_ls.h"
 #include "../../utilities/_hypre_utilities.h"
-#include "../../seq_mv/vector.h"
-/* #include "../../parcsr_mv/par_vector.h" */
 #include "../../parcsr_mv/_hypre_parcsr_mv.h"
 #include "HYPRE_MLMatrix.h"
 #include "HYPRE_MLMaxwell.h"
