@@ -566,8 +566,8 @@ int hypre_BiCGSTABLGetFinalRelativeResidualNorm( void   *bicgstab_vdata,
 #include "HYPRE.h"
 #include "IJ_mv/HYPRE_IJ_mv.h"
 #include "parcsr_mv/HYPRE_parcsr_mv.h"
-#include "parcsr_mv/parcsr_mv.h"
-#include "parcsr_ls/parcsr_ls.h"
+#include "parcsr_mv/_hypre_parcsr_mv.h"
+#include "parcsr_ls/_hypre_parcsr_ls.h"
 #include "parcsr_ls/HYPRE_parcsr_ls.h"
 #include "headers.h"
 
