@@ -13,7 +13,7 @@
 #include "IJ_mv/HYPRE_IJ_mv.h"
 #include "parcsr_mv/_hypre_parcsr_mv.h"
 #include "parcsr_ls/_hypre_parcsr_ls.h"
-#include "seq_mv/seq_mv.h"
+#include "seq_mv/_hypre_seq_mv.h"
 
 #include "HYPRE_FEI.h"
 
