@@ -10,7 +10,8 @@
  * HYPRE_FlexGMRES interface
  *
  *****************************************************************************/
-#include "krylov.h"
+
+#include "_hypre_krylov.h"
 
 /*--------------------------------------------------------------------------
  * HYPRE_FlexGMRESDestroy
