@@ -138,8 +138,8 @@ hypre_BiCGSTABFunctionsCreate(
    hypre_KrylovPtrToScaleVector   ScaleVector,
    hypre_KrylovPtrToAxpy          Axpy,
    hypre_KrylovPtrToCommInfo      CommInfo,
-   hypre_KrylovPtrToPrecond       Precond,
-   hypre_KrylovPtrToPrecondSetup  PrecondSetup
+   hypre_KrylovPtrToPrecondSetup  PrecondSetup,
+   hypre_KrylovPtrToPrecond       Precond
 );
 
 /**
