@@ -20,24 +20,22 @@
 
 hypre_FlexGMRESFunctions *
 hypre_FlexGMRESFunctionsCreate(
-   void *       (*CAlloc)        ( size_t count, size_t elt_size, HYPRE_MemoryLocation location ),
-   HYPRE_Int    (*Free)          ( void *ptr ),
-   HYPRE_Int    (*CommInfo)      ( void  *A, HYPRE_Int   *my_id,
-                                   HYPRE_Int   *num_procs ),
-   void *       (*CreateVector)  ( void *vector ),
-   void *       (*CreateVectorArray)  ( HYPRE_Int size, void *vectors ),
-   HYPRE_Int    (*DestroyVector) ( void *vector ),
-   void *       (*MatvecCreate)  ( void *A, void *x ),
-   HYPRE_Int    (*Matvec)        ( void *matvec_data, HYPRE_Complex alpha, void *A,
-                                   void *x, HYPRE_Complex beta, void *y ),
-   HYPRE_Int    (*MatvecDestroy) ( void *matvec_data ),
-   HYPRE_Real   (*InnerProd)     ( void *x, void *y ),
-   HYPRE_Int    (*CopyVector)    ( void *x, void *y ),
-   HYPRE_Int    (*ClearVector)   ( void *x ),
-   HYPRE_Int    (*ScaleVector)   ( HYPRE_Complex alpha, void *x ),
-   HYPRE_Int    (*Axpy)          ( HYPRE_Complex alpha, void *x, void *y ),
-   HYPRE_Int    (*PrecondSetup)  ( void *vdata, void *A, void *b, void *x ),
-   HYPRE_Int    (*Precond)       ( void *vdata, void *A, void *b, void *x )
+   hypre_KrylovPtrToCAlloc             CAlloc,
+   hypre_KrylovPtrToFree               Free,
+   hypre_KrylovPtrToCommInfo           CommInfo,
+   hypre_KrylovPtrToCreateVector       CreateVector,
+   hypre_KrylovPtrToCreateVectorArray  CreateVectorArray,
+   hypre_KrylovPtrToDestroyVector      DestroyVector,
+   hypre_KrylovPtrToMatvecCreate       MatvecCreate,
+   hypre_KrylovPtrToMatvec             Matvec,
+   hypre_KrylovPtrToMatvecDestroy      MatvecDestroy,
+   hypre_KrylovPtrToInnerProd          InnerProd,
+   hypre_KrylovPtrToCopyVector         CopyVector,
+   hypre_KrylovPtrToClearVector        ClearVector,
+   hypre_KrylovPtrToScaleVector        ScaleVector,
+   hypre_KrylovPtrToAxpy               Axpy,
+   hypre_KrylovPtrToPrecondSetup       PrecondSetup,
+   hypre_KrylovPtrToPrecond            Precond
 )
 {
    hypre_FlexGMRESFunctions * fgmres_functions;
@@ -210,7 +208,7 @@ hypre_FlexGMRESSetup( void *fgmres_vdata,
 
    HYPRE_Int            k_dim            = (fgmres_data -> k_dim);
    HYPRE_Int            max_iter         = (fgmres_data -> max_iter);
-   HYPRE_Int          (*precond_setup)(void*, void*, void*, void*) = (fgmres_functions->precond_setup);
+   hypre_KrylovPtrToPrecondSetup precond_setup = (fgmres_functions->precond_setup);
    void          *precond_data     = (fgmres_data -> precond_data);
 
    HYPRE_Int            rel_change       = (fgmres_data -> rel_change);
@@ -311,7 +309,7 @@ hypre_FlexGMRESSolve(void  *fgmres_vdata,
    void          **pre_vecs       = (fgmres_data ->pre_vecs);
    /*---*/
 
-   HYPRE_Int              (*precond)(void*, void*, void*, void*)   = (fgmres_functions -> precond);
+   hypre_KrylovPtrToPrecond precond      = (fgmres_functions -> precond);
    HYPRE_Int               *precond_data = (HYPRE_Int*)(fgmres_data -> precond_data);
 
    HYPRE_Int             print_level    = (fgmres_data -> print_level);
@@ -334,7 +332,7 @@ hypre_FlexGMRESSolve(void  *fgmres_vdata,
    HYPRE_Real weight;
    HYPRE_Real r_norm_0;
 
-   HYPRE_Int         (*modify_pc)(void*, HYPRE_Int, HYPRE_Real)   = (fgmres_functions -> modify_pc);
+   hypre_KrylovPtrToModifyPC modify_pc  = (fgmres_functions -> modify_pc);
 
    /* We are not checking rel. change for now... */
 
@@ -613,7 +611,7 @@ hypre_FlexGMRESSolve(void  *fgmres_vdata,
          if (cf_tol > 0.0)
          {
             cf_ave_0 = cf_ave_1;
-            cf_ave_1 = hypre_pow( r_norm / r_norm_0, 1.0 / (2.0 * iter));
+            cf_ave_1 = hypre_pow(r_norm / r_norm_0, 1.0 / (2.0 * (HYPRE_Real) iter));
 
             weight   = hypre_abs(cf_ave_1 - cf_ave_0);
             weight   = weight / hypre_max(cf_ave_1, cf_ave_0);
@@ -961,8 +959,8 @@ hypre_FlexGMRESGetStopCrit( void   *fgmres_vdata,
 
 HYPRE_Int
 hypre_FlexGMRESSetPrecond( void  *fgmres_vdata,
-                           HYPRE_Int  (*precond)(void*, void*, void*, void*),
-                           HYPRE_Int  (*precond_setup)(void*, void*, void*, void*),
+                           hypre_KrylovPtrToPrecond precond,
+                           hypre_KrylovPtrToPrecondSetup precond_setup,
                            void  *precond_data )
 {
    hypre_FlexGMRESData *fgmres_data = (hypre_FlexGMRESData *)fgmres_vdata;
@@ -1101,7 +1099,7 @@ hypre_FlexGMRESGetFinalRelativeResidualNorm( void   *fgmres_vdata,
 
 HYPRE_Int
 hypre_FlexGMRESSetModifyPC(void *fgmres_vdata,
-                           HYPRE_Int (*modify_pc)(void*, HYPRE_Int, HYPRE_Real))
+                           hypre_KrylovPtrToModifyPC modify_pc)
 {
    hypre_FlexGMRESData *fgmres_data = (hypre_FlexGMRESData *)fgmres_vdata;
    hypre_FlexGMRESFunctions *fgmres_functions = fgmres_data->functions;
