@@ -16,9 +16,23 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include "lobpcg.h"
-#include "fortran_matrix.h"
-#include "multivector.h"
+#include "_hypre_lobpcg.h"
+#include "_hypre_lapack.h"
+
+static HYPRE_Int dsygv_interface (HYPRE_Int *itype, char *jobz, char *uplo, HYPRE_Int *
+                                  n, HYPRE_Real *a, HYPRE_Int *lda, HYPRE_Real *b, HYPRE_Int *ldb,
+                                  HYPRE_Real *w, HYPRE_Real *work, HYPRE_Int *lwork, HYPRE_Int *info)
+{
+   hypre_dsygv(itype, jobz, uplo, n, a, lda, b, ldb, w, work, lwork, info);
+   return 0;
+}
+
+static HYPRE_Int dpotrf_interface (const char *uplo, HYPRE_Int *n, HYPRE_Real *a, HYPRE_Int *
+                                   lda, HYPRE_Int *info)
+{
+   hypre_dpotrf(uplo, n, a, lda, info);
+   return 0;
+}
 
 static HYPRE_Int
 lobpcg_chol( utilities_FortranMatrix* a,
@@ -31,8 +45,8 @@ lobpcg_chol( utilities_FortranMatrix* a,
    char uplo;
    HYPRE_Int ierr;
 
-   lda = utilities_FortranMatrixGlobalHeight( a );
-   n = utilities_FortranMatrixHeight( a );
+   lda  = (HYPRE_Int) utilities_FortranMatrixGlobalHeight( a );
+   n    = (HYPRE_Int) utilities_FortranMatrixHeight( a );
    aval = utilities_FortranMatrixValues( a );
    uplo = 'U';
 
@@ -67,9 +81,9 @@ lobpcg_solveGEVP(
    b = utilities_FortranMatrixValues( mtxB );
    lmd = utilities_FortranMatrixValues( eigVal );
 
-   n = utilities_FortranMatrixHeight( mtxA );
-   lda = utilities_FortranMatrixGlobalHeight( mtxA );
-   ldb = utilities_FortranMatrixGlobalHeight( mtxB );
+   n   = (HYPRE_Int) utilities_FortranMatrixHeight( mtxA );
+   lda = (HYPRE_Int) utilities_FortranMatrixGlobalHeight( mtxA );
+   ldb = (HYPRE_Int) utilities_FortranMatrixGlobalHeight( mtxB );
    lwork = 10 * n;
 
    work = hypre_CTAlloc(HYPRE_Real,  lwork, HYPRE_MEMORY_HOST);
@@ -83,21 +97,6 @@ lobpcg_solveGEVP(
 
 }
 
-
-static void
-lobpcg_MultiVectorByMultiVector(
-   mv_MultiVectorPtr x,
-   mv_MultiVectorPtr y,
-   utilities_FortranMatrix* xy
-)
-{
-   mv_MultiVectorByMultiVector( x, y,
-                                utilities_FortranMatrixGlobalHeight( xy ),
-                                utilities_FortranMatrixHeight( xy ),
-                                utilities_FortranMatrixWidth( xy ),
-                                utilities_FortranMatrixValues( xy ) );
-}
-
 static void
 lobpcg_MultiVectorByMatrix(
    mv_MultiVectorPtr x,
@@ -107,8 +106,8 @@ lobpcg_MultiVectorByMatrix(
 {
    mv_MultiVectorByMatrix( x,
                            utilities_FortranMatrixGlobalHeight( r ),
-                           utilities_FortranMatrixHeight( r ),
-                           utilities_FortranMatrixWidth( r ),
+                           (HYPRE_Int) utilities_FortranMatrixHeight( r ),
+                           (HYPRE_Int) utilities_FortranMatrixWidth( r ),
                            utilities_FortranMatrixValues( r ),
                            y );
 }
@@ -171,7 +170,7 @@ lobpcg_checkResiduals(
    HYPRE_Real atol;
    HYPRE_Real rtol;
 
-   n = utilities_FortranMatrixHeight( resNorms );
+   n = (HYPRE_Int) utilities_FortranMatrixHeight( resNorms );
 
    atol = tol.absolute;
    rtol = tol.relative;
@@ -230,7 +229,7 @@ lobpcg_solve( mv_MultiVectorPtr blockVectorX,
               HYPRE_Real * lambdaHistory_values,
 
               /* global height of the matrix (stored in fotran-style)  specified by previous argument */
-              HYPRE_Int lambdaHistory_gh,
+              HYPRE_BigInt lambdaHistory_gh,
 
               /* residual norms; argument should point to array of <blocksize> doubles */
               HYPRE_Real * residualNorms_values,
@@ -243,7 +242,7 @@ lobpcg_solve( mv_MultiVectorPtr blockVectorX,
               HYPRE_Real * residualNormsHistory_values,
 
               /* global height of the matrix (stored in fotran-style)  specified by previous argument */
-              HYPRE_Int residualNormsHistory_gh
+              HYPRE_BigInt residualNormsHistory_gh
 
             )
 {
@@ -293,7 +292,7 @@ lobpcg_solve( mv_MultiVectorPtr blockVectorX,
    mv_MultiVectorPtr     blockVectorBR; /* B*R */
    mv_MultiVectorPtr     blockVectorBP; /* B*P */
 
-   mv_MultiVectorPtr     blockVectorBY; /* B*Y */
+   mv_MultiVectorPtr     blockVectorBY = NULL; /* B*Y */
 
    utilities_FortranMatrix* gramA; /* Gram matrix for A */
    utilities_FortranMatrix* gramB; /* Gram matrix for B */
@@ -1081,3 +1080,424 @@ lobpcg_solve( mv_MultiVectorPtr blockVectorX,
 
    return exitFlag;
 }
+
+HYPRE_Int
+lobpcg_initialize( lobpcg_Data* data )
+{
+   (data->tolerance).absolute    = 1.0e-06;
+   (data->tolerance).relative    = 1.0e-06;
+   (data->maxIterations)         = 500;
+   (data->precondUsageMode)      = 0;
+   (data->verbosityLevel)        = 0;
+   (data->eigenvaluesHistory)    = utilities_FortranMatrixCreate();
+   (data->residualNorms)         = utilities_FortranMatrixCreate();
+   (data->residualNormsHistory)  = utilities_FortranMatrixCreate();
+
+   return 0;
+}
+
+HYPRE_Int
+lobpcg_clean( lobpcg_Data* data )
+{
+   utilities_FortranMatrixDestroy( data->eigenvaluesHistory );
+   utilities_FortranMatrixDestroy( data->residualNorms );
+   utilities_FortranMatrixDestroy( data->residualNormsHistory );
+
+   return 0;
+}
+
+HYPRE_Int
+hypre_LOBPCGDestroy( void *pcg_vdata )
+{
+   hypre_LOBPCGData      *pcg_data      = (hypre_LOBPCGData*)pcg_vdata;
+
+   if (pcg_data)
+   {
+      HYPRE_MatvecFunctions * mv = pcg_data->matvecFunctions;
+      if ( pcg_data->matvecData != NULL )
+      {
+         (*(mv->MatvecDestroy))(pcg_data->matvecData);
+         pcg_data->matvecData = NULL;
+      }
+      if ( pcg_data->matvecDataB != NULL )
+      {
+         (*(mv->MatvecDestroy))(pcg_data->matvecDataB);
+         pcg_data->matvecDataB = NULL;
+      }
+      if ( pcg_data->matvecDataT != NULL )
+      {
+         (*(mv->MatvecDestroy))(pcg_data->matvecDataT);
+         pcg_data->matvecDataT = NULL;
+      }
+
+      lobpcg_clean( &(pcg_data->lobpcgData) );
+
+      hypre_TFree( pcg_vdata, HYPRE_MEMORY_HOST);
+   }
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGSetup( void *pcg_vdata, void *A, void *b, void *x )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+   HYPRE_MatvecFunctions * mv = pcg_data->matvecFunctions;
+   HYPRE_Int  (*precond_setup)(void*, void*, void*, void*) = (pcg_data->precondFunctions).PrecondSetup;
+   void *precond_data = (pcg_data->precondData);
+
+   (pcg_data->A) = A;
+
+   if ( pcg_data->matvecData != NULL )
+   {
+      (*(mv->MatvecDestroy))(pcg_data->matvecData);
+   }
+   (pcg_data->matvecData) = (*(mv->MatvecCreate))(A, x);
+
+   if ( precond_setup != NULL )
+   {
+      if ( pcg_data->T == NULL )
+      {
+         precond_setup(precond_data, A, b, x);
+      }
+      else
+      {
+         precond_setup(precond_data, pcg_data->T, b, x);
+      }
+   }
+
+   return hypre_error_flag;
+}
+
+void
+lobpcg_MultiVectorByMultiVector(
+   mv_MultiVectorPtr x,
+   mv_MultiVectorPtr y,
+   utilities_FortranMatrix* xy
+)
+{
+   mv_MultiVectorByMultiVector( x, y,
+                                utilities_FortranMatrixGlobalHeight( xy ),
+                                (HYPRE_Int) utilities_FortranMatrixHeight( xy ),
+                                (HYPRE_Int) utilities_FortranMatrixWidth( xy ),
+                                utilities_FortranMatrixValues( xy ) );
+}
+
+HYPRE_Int
+hypre_LOBPCGSetupB( void *pcg_vdata, void *B, void *x )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+   HYPRE_MatvecFunctions * mv = pcg_data->matvecFunctions;
+
+   (pcg_data->B) = B;
+
+   if ( pcg_data->matvecDataB != NULL )
+   {
+      (*(mv->MatvecDestroy))(pcg_data -> matvecDataB);
+   }
+   (pcg_data->matvecDataB) = (*(mv->MatvecCreate))(B, x);
+   if ( B != NULL )
+   {
+      (pcg_data->matvecDataB) = (*(mv->MatvecCreate))(B, x);
+   }
+   else
+   {
+      (pcg_data->matvecDataB) = NULL;
+   }
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGSetupT( void *pcg_vdata, void *T, void *x )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+   HYPRE_MatvecFunctions * mv = pcg_data->matvecFunctions;
+
+   (pcg_data -> T) = T;
+
+   if ( pcg_data->matvecDataT != NULL )
+   {
+      (*(mv->MatvecDestroy))(pcg_data->matvecDataT);
+   }
+   if ( T != NULL )
+   {
+      (pcg_data->matvecDataT) = (*(mv->MatvecCreate))(T, x);
+   }
+   else
+   {
+      (pcg_data->matvecDataT) = NULL;
+   }
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGSetTol( void* pcg_vdata, HYPRE_Real tol )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+
+   lobpcg_absoluteTolerance(pcg_data->lobpcgData) = tol;
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGSetRTol( void* pcg_vdata, HYPRE_Real tol )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*) pcg_vdata;
+
+   lobpcg_relativeTolerance(pcg_data->lobpcgData) = tol;
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGSetMaxIter( void* pcg_vdata, HYPRE_Int max_iter  )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+
+   lobpcg_maxIterations(pcg_data->lobpcgData) = max_iter;
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGSetPrecondUsageMode( void* pcg_vdata, HYPRE_Int mode  )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+
+   lobpcg_precondUsageMode(pcg_data->lobpcgData) = mode;
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGGetPrecond( void         *pcg_vdata,
+                        HYPRE_Solver *precond_data_ptr )
+{
+   hypre_LOBPCGData* pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+
+   *precond_data_ptr = (HYPRE_Solver)(pcg_data -> precondData);
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGSetPrecond( void  *pcg_vdata,
+                        HYPRE_Int  (*precond)(void*, void*, void*, void*),
+                        HYPRE_Int  (*precond_setup)(void*, void*, void*, void*),
+                        void  *precond_data )
+{
+   hypre_LOBPCGData* pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+
+   (pcg_data->precondFunctions).Precond      = precond;
+   (pcg_data->precondFunctions).PrecondSetup = precond_setup;
+   (pcg_data->precondData)                   = precond_data;
+
+   return hypre_error_flag;
+}
+
+HYPRE_Int
+hypre_LOBPCGSetPrintLevel( void *pcg_vdata, HYPRE_Int level )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)pcg_vdata;
+
+   lobpcg_verbosityLevel(pcg_data->lobpcgData) = level;
+
+   return hypre_error_flag;
+}
+
+void
+hypre_LOBPCGPreconditioner( void *vdata, void* x, void* y )
+{
+   hypre_LOBPCGData *data = (hypre_LOBPCGData*)vdata;
+   mv_InterfaceInterpreter* ii = data->interpreter;
+   HYPRE_Int (*precond)(void*, void*, void*, void*) = (data->precondFunctions).Precond;
+
+   if ( precond == NULL )
+   {
+      (*(ii->CopyVector))(x, y);
+      return;
+   }
+
+   if ( lobpcg_precondUsageMode(data->lobpcgData) == 0 )
+   {
+      (*(ii->ClearVector))(y);
+   }
+   else
+   {
+      (*(ii->CopyVector))(x, y);
+   }
+
+   if ( data->T == NULL )
+   {
+      precond(data->precondData, data->A, x, y);
+   }
+   else
+   {
+      precond(data->precondData, data->T, x, y);
+   }
+}
+
+void
+hypre_LOBPCGOperatorA( void *pcg_vdata, void* x, void* y )
+{
+   hypre_LOBPCGData*           pcg_data    = (hypre_LOBPCGData*)pcg_vdata;
+   HYPRE_MatvecFunctions * mv = pcg_data->matvecFunctions;
+   void*                      matvec_data = (pcg_data -> matvecData);
+
+   (*(mv->Matvec))(matvec_data, 1.0, pcg_data->A, x, 0.0, y);
+}
+
+void
+hypre_LOBPCGOperatorB( void *pcg_vdata, void* x, void* y )
+{
+   hypre_LOBPCGData*           pcg_data    = (hypre_LOBPCGData*)pcg_vdata;
+   mv_InterfaceInterpreter* ii          = pcg_data->interpreter;
+   HYPRE_MatvecFunctions * mv = pcg_data->matvecFunctions;
+   void*                       matvec_data = (pcg_data -> matvecDataB);
+
+   if ( pcg_data->B == NULL )
+   {
+      (*(ii->CopyVector))(x, y);
+
+      /* a test */
+      /*
+        (*(ii->ScaleVector))(2.0, y);
+      */
+
+      return;
+   }
+
+   (*(mv->Matvec))(matvec_data, 1.0, pcg_data->B, x, 0.0, y);
+}
+
+void
+hypre_LOBPCGMultiPreconditioner( void *data, void * x, void*  y )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)data;
+   mv_InterfaceInterpreter* ii = pcg_data->interpreter;
+
+   ii->Eval( hypre_LOBPCGPreconditioner, data, x, y );
+}
+
+void
+hypre_LOBPCGMultiOperatorA( void *data, void * x, void*  y )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)data;
+   mv_InterfaceInterpreter* ii = pcg_data->interpreter;
+
+   ii->Eval( hypre_LOBPCGOperatorA, data, x, y );
+}
+
+void
+hypre_LOBPCGMultiOperatorB( void *data, void * x, void*  y )
+{
+   hypre_LOBPCGData *pcg_data = (hypre_LOBPCGData*)data;
+   mv_InterfaceInterpreter* ii = pcg_data->interpreter;
+
+   ii->Eval( hypre_LOBPCGOperatorB, data, x, y );
+}
+
+HYPRE_Int
+hypre_LOBPCGSolve( void *vdata,
+                   mv_MultiVectorPtr con,
+                   mv_MultiVectorPtr vec,
+                   HYPRE_Real* val )
+{
+   hypre_LOBPCGData* data = (hypre_LOBPCGData*)vdata;
+   HYPRE_Int (*precond)(void*, void*, void*, void*) = (data->precondFunctions).Precond;
+   void* opB = data->B;
+
+   void (*prec)( void*, void*, void* );
+   void (*operatorA)( void*, void*, void* );
+   void (*operatorB)( void*, void*, void* );
+
+   HYPRE_Int maxit = lobpcg_maxIterations(data->lobpcgData);
+   HYPRE_Int verb  = lobpcg_verbosityLevel(data->lobpcgData);
+
+   HYPRE_Int n = mv_MultiVectorWidth( vec );
+   lobpcg_BLASLAPACKFunctions blap_fn;
+
+   utilities_FortranMatrix* lambdaHistory;
+   utilities_FortranMatrix* residuals;
+   utilities_FortranMatrix* residualsHistory;
+
+   lambdaHistory  = lobpcg_eigenvaluesHistory(data->lobpcgData);
+   residuals = lobpcg_residualNorms(data->lobpcgData);
+   residualsHistory = lobpcg_residualNormsHistory(data->lobpcgData);
+
+   utilities_FortranMatrixAllocateData( n, maxit + 1, lambdaHistory );
+   utilities_FortranMatrixAllocateData( n, 1,      residuals );
+   utilities_FortranMatrixAllocateData( n, maxit + 1, residualsHistory );
+
+   if ( precond != NULL )
+   {
+      prec = hypre_LOBPCGMultiPreconditioner;
+   }
+   else
+   {
+      prec = NULL;
+   }
+
+   operatorA = hypre_LOBPCGMultiOperatorA;
+
+   if ( opB != NULL )
+   {
+      operatorB = hypre_LOBPCGMultiOperatorB;
+   }
+   else
+   {
+      operatorB = NULL;
+   }
+
+   blap_fn.dsygv = dsygv_interface;
+   blap_fn.dpotrf = dpotrf_interface;
+
+   lobpcg_solve( vec,
+                 vdata, operatorA,
+                 vdata, operatorB,
+                 vdata, prec,
+                 con,
+                 blap_fn,
+                 lobpcg_tolerance(data->lobpcgData), maxit, verb,
+                 &(lobpcg_iterationNumber(data->lobpcgData)),
+                 val,
+                 utilities_FortranMatrixValues(lambdaHistory),
+                 utilities_FortranMatrixGlobalHeight(lambdaHistory),
+                 utilities_FortranMatrixValues(residuals),
+                 utilities_FortranMatrixValues(residualsHistory),
+                 utilities_FortranMatrixGlobalHeight(residualsHistory)
+               );
+
+   return hypre_error_flag;
+}
+
+utilities_FortranMatrix*
+hypre_LOBPCGResidualNorms( void *vdata )
+{
+   hypre_LOBPCGData *data = (hypre_LOBPCGData*)vdata;
+   return (lobpcg_residualNorms(data->lobpcgData));
+}
+
+utilities_FortranMatrix*
+hypre_LOBPCGResidualNormsHistory( void *vdata )
+{
+   hypre_LOBPCGData *data = (hypre_LOBPCGData*)vdata;
+   return (lobpcg_residualNormsHistory(data->lobpcgData));
+}
+
+utilities_FortranMatrix*
+hypre_LOBPCGEigenvaluesHistory( void *vdata )
+{
+   hypre_LOBPCGData *data = (hypre_LOBPCGData*)vdata;
+   return (lobpcg_eigenvaluesHistory(data->lobpcgData));
+}
+
+HYPRE_Int
+hypre_LOBPCGIterations( void* vdata )
+{
+   hypre_LOBPCGData *data = (hypre_LOBPCGData*)vdata;
+   return (lobpcg_iterationNumber(data->lobpcgData));
+}
