@@ -15,7 +15,7 @@
 
 #include "HYPRE.h"
 #include "parcsr_mv/_hypre_parcsr_mv.h"
-#include "seq_mv/seq_mv.h"
+#include "seq_mv/_hypre_seq_mv.h"
 
 /*--------------------------------------------------------------------------
  * hypre_ParCSRMatrixMatvec
