@@ -33,6 +33,9 @@ hypre_BoomerAMGCoarsenPMISDevice( hypre_ParCSRMatrix    *S,
                                   HYPRE_Int              debug_flag,
                                   hypre_IntArray       **CF_marker_ptr )
 {
+   HYPRE_UNUSED_VAR(debug_flag);
+   HYPRE_UNUSED_VAR(CF_init);
+
    MPI_Comm                  comm            = hypre_ParCSRMatrixComm(S);
    hypre_ParCSRCommPkg      *comm_pkg        = hypre_ParCSRMatrixCommPkg(S);
    hypre_ParCSRCommHandle   *comm_handle;
@@ -173,7 +176,7 @@ hypre_BoomerAMGCoarsenPMISDevice( hypre_ParCSRMatrix    *S,
          /* RL: make sure send_buf is ready before issuing GPU-GPU MPI */
          if (hypre_GetGpuAwareMPI())
          {
-            hypre_ForceSyncComputeStream(hypre_handle());
+            hypre_ForceSyncComputeStream();
          }
 #endif
 
@@ -215,7 +218,7 @@ hypre_BoomerAMGCoarsenPMISDevice( hypre_ParCSRMatrix    *S,
                                               graph_diag,
                                               graph_diag + graph_diag_size,
                                               diag_iwork,
-                                              thrust::identity<HYPRE_Int>() );
+                                              HYPRE_THRUST_IDENTITY(HYPRE_Int) );
 #endif
 
       graph_diag_size = new_end - graph_diag;
@@ -248,6 +251,8 @@ hypre_GetGlobalMeasureDevice( hypre_ParCSRMatrix  *S,
                               HYPRE_Real          *measure_offd,
                               HYPRE_Real          *real_send_buf )
 {
+   HYPRE_UNUSED_VAR(CF_init);
+
    hypre_ParCSRCommHandle   *comm_handle;
    HYPRE_Int                 num_sends       = hypre_ParCSRCommPkgNumSends(comm_pkg);
    hypre_CSRMatrix          *S_diag          = hypre_ParCSRMatrixDiag(S);
@@ -260,7 +265,7 @@ hypre_GetGlobalMeasureDevice( hypre_ParCSRMatrix  *S,
    if (hypre_GetGpuAwareMPI())
    {
       /* RL: make sure measure_offd is ready before issuing GPU-GPU MPI */
-      hypre_ForceSyncComputeStream(hypre_handle());
+      hypre_ForceSyncComputeStream();
    }
 
    /* send local column nnz of the offd part to neighbors */
@@ -413,7 +418,7 @@ hypre_PMISCoarseningInitDevice( hypre_ParCSRMatrix  *S,               /* in */
    /* RL: make sure real_send_buf is ready before issuing GPU-GPU MPI */
    if (hypre_GetGpuAwareMPI())
    {
-      hypre_ForceSyncComputeStream(hypre_handle());
+      hypre_ForceSyncComputeStream();
    }
 #endif
 
@@ -437,7 +442,7 @@ hypre_PMISCoarseningInitDevice( hypre_ParCSRMatrix  *S,               /* in */
                                 thrust::make_counting_iterator(num_rows_diag),
                                 CF_marker_diag,
                                 graph_diag,
-                                thrust::identity<HYPRE_Int>());
+                                HYPRE_THRUST_IDENTITY(HYPRE_Int));
 #endif
 
    *graph_diag_size = new_end - graph_diag;
@@ -566,6 +571,8 @@ hypre_PMISCoarseningUpdateCFDevice( hypre_ParCSRMatrix  *S,               /* in
                                     HYPRE_Real          *real_send_buf,
                                     HYPRE_Int           *int_send_buf )
 {
+   HYPRE_UNUSED_VAR(int_send_buf);
+
    hypre_CSRMatrix *S_diag    = hypre_ParCSRMatrixDiag(S);
    HYPRE_Int       *S_diag_i  = hypre_CSRMatrixI(S_diag);
    HYPRE_Int       *S_diag_j  = hypre_CSRMatrixJ(S_diag);
@@ -611,7 +618,7 @@ hypre_PMISCoarseningUpdateCFDevice( hypre_ParCSRMatrix  *S,               /* in
    /* RL: make sure real_send_buf is ready before issuing GPU-GPU MPI */
    if (hypre_GetGpuAwareMPI())
    {
-      hypre_ForceSyncComputeStream(hypre_handle());
+      hypre_ForceSyncComputeStream();
    }
 #endif
 
@@ -635,7 +642,7 @@ hypre_PMISCoarseningUpdateCFDevice( hypre_ParCSRMatrix  *S,               /* in
    /* RL: make sure int_send_buf is ready before issuing GPU-GPU MPI */
    if (hypre_GetGpuAwareMPI())
    {
-      hypre_ForceSyncComputeStream(hypre_handle());
+      hypre_ForceSyncComputeStream();
    }
 #endif
 
