@@ -50,7 +50,7 @@ GenerateLaplacian9pt( MPI_Comm comm,
    HYPRE_BigInt *ny_part;
 
    HYPRE_Int num_procs;
-   HYPRE_Int P_busy, Q_busy;
+   HYPRE_BigInt P_busy, Q_busy;
 
    hypre_MPI_Comm_size(comm, &num_procs);
 
@@ -70,8 +70,8 @@ GenerateLaplacian9pt( MPI_Comm comm,
    diag_i = hypre_CTAlloc(HYPRE_Int, local_num_rows + 1, HYPRE_MEMORY_HOST);
    offd_i = hypre_CTAlloc(HYPRE_Int, local_num_rows + 1, HYPRE_MEMORY_HOST);
 
-   P_busy = hypre_min(nx, P);
-   Q_busy = hypre_min(ny, Q);
+   P_busy = hypre_min(nx, (HYPRE_BigInt) P);
+   Q_busy = hypre_min(ny, (HYPRE_BigInt) Q);
 
    num_cols_offd = 0;
    if (p) { num_cols_offd += ny_local; }
