@@ -380,9 +380,10 @@ hypre_BoomerAMGBuildRestrAIR( hypre_ParCSRMatrix   *A,
        * we need from these rows and put them in Ai and bi*/
 
       /* clear DAi and bi */
-      memset(DAi, 0, local_size * local_size * sizeof(HYPRE_Complex));
-      memset(Dxi, 0, local_size * sizeof(HYPRE_Complex));
-      memset(Dbi, 0, local_size * sizeof(HYPRE_Complex));
+      hypre_Memset(DAi, 0, (size_t) (local_size * local_size) * sizeof(HYPRE_Complex),
+                   HYPRE_MEMORY_HOST);
+      hypre_Memset(Dxi, 0, (size_t) local_size * sizeof(HYPRE_Complex), HYPRE_MEMORY_HOST);
+      hypre_Memset(Dbi, 0, (size_t) local_size * sizeof(HYPRE_Complex), HYPRE_MEMORY_HOST);
 
       /* we will populate Ai, bi row-by-row
        * rr is the local dense matrix row counter */
@@ -819,7 +820,7 @@ colmaj_mvT(HYPRE_Complex *A,
            HYPRE_Complex *y,
            HYPRE_Int      n)
 {
-   memset(y, 0, n * sizeof(HYPRE_Complex));
+   hypre_Memset(y, 0, (size_t) n * sizeof(HYPRE_Complex), HYPRE_MEMORY_HOST);
    HYPRE_Int i, j;
    for (i = 0; i < n; i++)
    {
