@@ -31,8 +31,8 @@ GenerateRotate7pt( MPI_Comm       comm,
    HYPRE_Real *diag_data;
 
    HYPRE_Int    *offd_i;
-   HYPRE_Int    *offd_j;
-   HYPRE_Real *offd_data;
+   HYPRE_Int    *offd_j = NULL;
+   HYPRE_Real *offd_data = NULL;
 
    HYPRE_Real *value;
    HYPRE_Real ac, bc, cc, s, c, pi, x;
@@ -53,7 +53,7 @@ GenerateRotate7pt( MPI_Comm       comm,
    HYPRE_BigInt *ny_part;
 
    HYPRE_Int num_procs;
-   HYPRE_Int P_busy, Q_busy;
+   HYPRE_BigInt P_busy, Q_busy;
 
    hypre_MPI_Comm_size(comm, &num_procs);
 
@@ -86,8 +86,8 @@ GenerateRotate7pt( MPI_Comm       comm,
    diag_i = hypre_CTAlloc(HYPRE_Int,  local_num_rows + 1, HYPRE_MEMORY_HOST);
    offd_i = hypre_CTAlloc(HYPRE_Int,  local_num_rows + 1, HYPRE_MEMORY_HOST);
 
-   P_busy = hypre_min(nx, P);
-   Q_busy = hypre_min(ny, Q);
+   P_busy = hypre_min(nx, (HYPRE_BigInt) P);
+   Q_busy = hypre_min(ny, (HYPRE_BigInt) Q);
 
    num_cols_offd = 0;
    if (p) { num_cols_offd += ny_local; }
