@@ -49,7 +49,7 @@ hypre_ParCSRMatrixGenerateFFFCHost( hypre_ParCSRMatrix  *A,
    hypre_CSRMatrix    *S_diag   = S ? hypre_ParCSRMatrixDiag(S) : A_diag;
    HYPRE_Int          *S_diag_i = hypre_CSRMatrixI(S_diag);
    HYPRE_Int          *S_diag_j = hypre_CSRMatrixJ(S_diag);
-   HYPRE_Int           skip_diag = S ? 0 : 1;
+   HYPRE_Int           S_equals_A = (S == NULL);  /* Flag indicating S is the same as A */
    /* off-diag part of S */
    hypre_CSRMatrix    *S_offd   = S ? hypre_ParCSRMatrixOffd(S) : A_offd;
    HYPRE_Int          *S_offd_i = hypre_CSRMatrixI(S_offd);
@@ -299,17 +299,29 @@ hypre_ParCSRMatrixGenerateFFFCHost( hypre_ParCSRMatrix  *A,
          if (CF_marker[i] < 0)
          {
             row++;
-            d_count_FF++; /* account for diagonal element */
-            for (j = S_diag_i[i] + skip_diag; j < S_diag_i[i + 1]; j++)
+            /* account for diagonal element if it exists */
+            if (A_diag_i[i] < A_diag_i[i + 1] && A_diag_j[A_diag_i[i]] == i)
             {
-               jj = S_diag_j[j];
-               if (CF_marker[jj] > 0)
+               d_count_FF++;
+            }
+            /* When S==A, skip diagonal in S loop if it exists (since handled above) */
+            {
+               HYPRE_Int s_start = S_diag_i[i];
+               if (S_equals_A && s_start < S_diag_i[i + 1] && S_diag_j[s_start] == i)
                {
-                  d_count_FC++;
+                  s_start++;
                }
-               else
+               for (j = s_start; j < S_diag_i[i + 1]; j++)
                {
-                  d_count_FF++;
+                  jj = S_diag_j[j];
+                  if (CF_marker[jj] > 0)
+                  {
+                     d_count_FC++;
+                  }
+                  else
+                  {
+                     d_count_FF++;
+                  }
                }
             }
             A_FF_diag_i[row] = d_count_FF;
@@ -381,23 +393,40 @@ hypre_ParCSRMatrixGenerateFFFCHost( hypre_ParCSRMatrix  *A,
          {
             HYPRE_Int jS, jA;
             row++;
+            /* copy diagonal element if it exists */
             jA = A_diag_i[i];
-            A_FF_diag_j[d_count_FF] = fine_to_fine[A_diag_j[jA]];
-            A_FF_diag_data[d_count_FF++] = A_diag_data[jA++];
-            for (j = S_diag_i[i] + skip_diag; j < S_diag_i[i + 1]; j++)
+            if (jA < A_diag_i[i + 1] && A_diag_j[jA] == i)
             {
-               jA = A_diag_i[i] + 1;
-               jS = S_diag_j[j];
-               while (A_diag_j[jA] != jS) { jA++; }
-               if (CF_marker[S_diag_j[j]] > 0)
+               A_FF_diag_j[d_count_FF] = fine_to_fine[A_diag_j[jA]];
+               A_FF_diag_data[d_count_FF++] = A_diag_data[jA];
+            }
+            /* When S==A, skip diagonal in S loop if it exists (since handled above) */
+            {
+               HYPRE_Int s_start = S_diag_i[i];
+               if (S_equals_A && s_start < S_diag_i[i + 1] && S_diag_j[s_start] == i)
                {
-                  A_FC_diag_j[d_count_FC] = fine_to_coarse[A_diag_j[jA]];
-                  A_FC_diag_data[d_count_FC++] = A_diag_data[jA++];
+                  s_start++;
                }
-               else
+               for (j = s_start; j < S_diag_i[i + 1]; j++)
                {
-                  A_FF_diag_j[d_count_FF] = fine_to_fine[A_diag_j[jA]];
-                  A_FF_diag_data[d_count_FF++] = A_diag_data[jA++];
+                  /* Start search after diagonal if it exists, otherwise from the first entry */
+                  jA = A_diag_i[i];
+                  if (jA < A_diag_i[i + 1] && A_diag_j[jA] == i)
+                  {
+                     jA++;  /* Skip diagonal */
+                  }
+                  jS = S_diag_j[j];
+                  while (A_diag_j[jA] != jS) { jA++; }
+                  if (CF_marker[S_diag_j[j]] > 0)
+                  {
+                     A_FC_diag_j[d_count_FC] = fine_to_coarse[A_diag_j[jA]];
+                     A_FC_diag_data[d_count_FC++] = A_diag_data[jA++];
+                  }
+                  else
+                  {
+                     A_FF_diag_j[d_count_FF] = fine_to_fine[A_diag_j[jA]];
+                     A_FF_diag_data[d_count_FF++] = A_diag_data[jA++];
+                  }
                }
             }
             A_FF_diag_i[row] = d_count_FF;
@@ -1506,7 +1535,7 @@ hypre_ParCSRMatrixGenerateFFFCD3( hypre_ParCSRMatrix *A,
                   A_FF_offd_data[o_count_FF++] = A_offd_data[jA++];
                }
             }
-            if (sum) { D_lambda[rowc] = D_lambda[rowc] / sum; }
+            if (sum != 0.0) { D_lambda[rowc] = D_lambda[rowc] / sum; }
             rowc++;
             A_FF_diag_i[row] = d_count_FF;
             A_FC_diag_i[rowc] = d_count_FC;
@@ -1549,7 +1578,7 @@ hypre_ParCSRMatrixGenerateFFFCD3( hypre_ParCSRMatrix *A,
                   D_lambda[rowc] += A_offd_data[jA];
                }
             }
-            if (sum) { D_lambda[rowc] = D_lambda[rowc] / sum; }
+            if (sum != 0.0) { D_lambda[rowc] = D_lambda[rowc] / sum; }
             rowc++;
             A_FC_diag_i[rowc] = d_count_FC;
             A_FC_offd_i[rowc] = o_count_FC;
