@@ -14,7 +14,7 @@
 #include "_hypre_parcsr_mv.h"
 
 /* This is used only in the function below */
-#define CONTACT(a,b)  (contact_list[(a)*3+(b)])
+#define CONTACT(a,b)  (contact_list[(a) * 3 + (b)])
 
 /*--------------------------------------------------------------------
  * hypre_LocateAssumedPartition
@@ -108,13 +108,12 @@ hypre_LocateAssumedPartition(MPI_Comm comm, HYPRE_BigInt row_start, HYPRE_BigInt
 
    contact_list_length = 0;
    contact_list_storage = 5;
-   contact_list = hypre_TAlloc(HYPRE_BigInt,  contact_list_storage * 3,
+   contact_list = hypre_TAlloc(HYPRE_BigInt, contact_list_storage * 3,
                                HYPRE_MEMORY_HOST); /*each contact needs 3 ints */
 
    for (i = 0; i < contact_ranges; i++)
    {
-
-      /*get start and end row owners */
+      /* get start and end row owners */
       hypre_GetAssumedPartitionProcFromRow(comm, contact_row_start[i], global_first_row,
                                            global_num_rows, &owner_start);
       hypre_GetAssumedPartitionProcFromRow(comm, contact_row_end[i], global_first_row,
@@ -172,15 +171,14 @@ hypre_LocateAssumedPartition(MPI_Comm comm, HYPRE_BigInt row_start, HYPRE_BigInt
       }
    }
 
-   requests = hypre_CTAlloc(hypre_MPI_Request,  contact_list_length, HYPRE_MEMORY_HOST);
-   statuses = hypre_CTAlloc(hypre_MPI_Status,  contact_list_length, HYPRE_MEMORY_HOST);
+   requests = hypre_CTAlloc(hypre_MPI_Request, contact_list_length, HYPRE_MEMORY_HOST);
+   statuses = hypre_CTAlloc(hypre_MPI_Status, contact_list_length, HYPRE_MEMORY_HOST);
 
    /*send out messages */
    for (i = 0; i < contact_list_length; i++)
    {
-      hypre_MPI_Isend(&CONTACT(i, 1), 2, HYPRE_MPI_BIG_INT, CONTACT(i, 0), flag1,
-                      comm, &requests[i]);
-      /*hypre_MPI_COMM_WORLD, &requests[i]);*/
+      hypre_MPI_Isend(&CONTACT(i, 1), 2, HYPRE_MPI_BIG_INT,
+                      (HYPRE_Int) CONTACT(i, 0), flag1, comm, &requests[i]);
    }
 
    /*-----------------------------------------------------------
@@ -203,7 +201,7 @@ hypre_LocateAssumedPartition(MPI_Comm comm, HYPRE_BigInt row_start, HYPRE_BigInt
    {
       /*locate_row_start[0] = part->row_start;*/
       /*locate_ranges++;*/
-      locate_row_count += part->row_end - part->row_start + 1;
+      locate_row_count += (HYPRE_Int) (part->row_end - part->row_start + 1);
    }
    else /* the two regions overlap */
    {
@@ -212,7 +210,7 @@ hypre_LocateAssumedPartition(MPI_Comm comm, HYPRE_BigInt row_start, HYPRE_BigInt
          /* check for locate rows on the low end of the local range */
          /*locate_row_start[0] = part->row_start;*/
          /*locate_ranges++;*/
-         locate_row_count += (row_start - 1) - part->row_start + 1;
+         locate_row_count += (HYPRE_Int) (row_start - part->row_start);
       }
       if (row_end < part->row_end) /* check the high end */
       {
@@ -225,24 +223,22 @@ hypre_LocateAssumedPartition(MPI_Comm comm, HYPRE_BigInt row_start, HYPRE_BigInt
            locate_row_start[0] = row_end +1;
            }*/
          /*locate_ranges++;*/
-         locate_row_count += part->row_end - (row_end + 1) + 1;
+         locate_row_count += (HYPRE_Int) (part->row_end - row_end);
       }
    }
 
-
    /*-----------------------------------------------------------
     * Receive messages from other procs telling us where
     * all our  locate rows actually reside
     *-----------------------------------------------------------*/
 
-
    /* we will keep a partition of our assumed partition - list ourselves
       first.  We will sort later with an additional index.
       In practice, this should only contain a few processors */
 
    /*which part do I own?*/
    tmp_row_start = hypre_max(part->row_start, row_start);
-   tmp_row_end = hypre_min(row_end, part->row_end);
+   tmp_row_end   = hypre_min(row_end, part->row_end);
 
    if (tmp_row_start <= tmp_row_end)
    {
@@ -260,26 +256,24 @@ hypre_LocateAssumedPartition(MPI_Comm comm, HYPRE_BigInt row_start, HYPRE_BigInt
 
    while (rows_found != locate_row_count)
    {
-      hypre_MPI_Recv( tmp_range, 2, HYPRE_MPI_BIG_INT, hypre_MPI_ANY_SOURCE,
-                      flag1, comm, &status0);
-      /*flag1 , hypre_MPI_COMM_WORLD, &status0);*/
+      hypre_MPI_Recv(tmp_range, 2, HYPRE_MPI_BIG_INT, hypre_MPI_ANY_SOURCE,
+                     flag1, comm, &status0);
 
       if (part->length == part->storage_length)
       {
          part->storage_length += 10;
-         part->proc_list = hypre_TReAlloc(part->proc_list,  HYPRE_Int,  part->storage_length,
-                                          HYPRE_MEMORY_HOST);
-         part->row_start_list = hypre_TReAlloc(part->row_start_list,  HYPRE_BigInt,  part->storage_length,
-                                               HYPRE_MEMORY_HOST);
-         part->row_end_list = hypre_TReAlloc(part->row_end_list,  HYPRE_BigInt,  part->storage_length,
-                                             HYPRE_MEMORY_HOST);
-
+         part->proc_list = hypre_TReAlloc(part->proc_list, HYPRE_Int,
+                                          part->storage_length, HYPRE_MEMORY_HOST);
+         part->row_start_list = hypre_TReAlloc(part->row_start_list, HYPRE_BigInt,
+                                               part->storage_length, HYPRE_MEMORY_HOST);
+         part->row_end_list = hypre_TReAlloc(part->row_end_list, HYPRE_BigInt,
+                                             part->storage_length, HYPRE_MEMORY_HOST);
       }
       part->row_start_list[part->length] = tmp_range[0];
-      part->row_end_list[part->length] = tmp_range[1];
+      part->row_end_list[part->length]   = tmp_range[1];
 
       part->proc_list[part->length] = status0.hypre_MPI_SOURCE;
-      rows_found += tmp_range[1] - tmp_range[0] + 1;
+      rows_found += (HYPRE_Int) (tmp_range[1] - tmp_range[0]) + 1;
 
       part->length++;
    }
