@@ -11,7 +11,7 @@
  *
  *****************************************************************************/
 
-#include "seq_mv.h"
+#include "_hypre_seq_mv.h"
 
 /*--------------------------------------------------------------------------
  * HYPRE_MultiblockMatrixCreate
