@@ -314,7 +314,9 @@ hypre_SeqVectorInitialize_v2( hypre_Vector         *vector,
     * when being used, and freed */
    if (!hypre_VectorData(vector))
    {
-      hypre_VectorData(vector) = hypre_CTAlloc(HYPRE_Complex, num_vectors * size, memory_location);
+      /* Cast to size_t before multiplication to avoid integer overflow when HYPRE_Int is 32-bit */
+      hypre_VectorData(vector) = hypre_CTAlloc(HYPRE_Complex, (size_t)num_vectors * (size_t)size,
+                                               memory_location);
    }
 
    return hypre_error_flag;
@@ -377,8 +379,9 @@ hypre_SeqVectorResize( hypre_Vector *vector,
    HYPRE_Int  method        = hypre_VectorMultiVecStorageMethod(vector);
    HYPRE_Int  size          = hypre_VectorSize(vector);
    HYPRE_Int  num_vectors   = hypre_VectorNumVectors(vector);
-   HYPRE_Int  total_size    = num_vectors * size;
-   HYPRE_Int  total_size_in = num_vectors_in * size_in;
+   /* Cast to size_t before multiplication to avoid integer overflow when HYPRE_Int is 32-bit */
+   size_t     total_size    = (size_t)num_vectors * (size_t)size;
+   size_t     total_size_in = (size_t)num_vectors_in * (size_t)size_in;
 
    /* Reallocate data array */
    if (total_size_in > total_size)
@@ -659,7 +662,8 @@ hypre_SeqVectorCopy( hypre_Vector *x,
 
    hypre_GpuProfilingPushRange("SeqVectorCopy");
 
-   size_t size = hypre_min(hypre_VectorSize(x), hypre_VectorSize(y)) * hypre_VectorNumVectors(x);
+   HYPRE_Int size = hypre_min(hypre_VectorSize(x), hypre_VectorSize(y)) *
+                    hypre_VectorNumVectors(x);
 
    hypre_TMemcpy( hypre_VectorData(y),
                   hypre_VectorData(x),
@@ -1631,9 +1635,9 @@ hypre_SeqVectorPointwiseProduct( hypre_Vector  *x,
 {
    HYPRE_Complex *x_data = hypre_VectorData(x);
    HYPRE_Complex *y_data = hypre_VectorData(y);
-   HYPRE_Complex  x_size = hypre_VectorSize(x);
-   HYPRE_Complex  y_size = hypre_VectorSize(y);
-   HYPRE_Complex  z_size = hypre_VectorSize(*z_ptr);
+   HYPRE_Int      x_size = hypre_VectorSize(x);
+   HYPRE_Int      y_size = hypre_VectorSize(y);
+   HYPRE_Int      z_size = hypre_VectorSize(*z_ptr);
 
    /* Check if vectors are initialized */
    if ((!x_data && !x_size) || (!y_data && !y_size))
