@@ -6,7 +6,7 @@
  ******************************************************************************/
 
 #include "_hypre_struct_ls.h"
-#include "fortran.h"
+#include "_hypre_fortran.h"
 
 #ifdef __cplusplus
 extern "C" {
