@@ -199,6 +199,23 @@ HYPRE_StructPFMGGetRAPType( HYPRE_StructSolver solver,
    return ( hypre_PFMGGetRAPType( (void *) solver, rap_type) );
 }
 
+/*--------------------------------------------------------------------------
+ *--------------------------------------------------------------------------*/
+
+HYPRE_Int
+HYPRE_StructPFMGSetMatmultType( HYPRE_StructSolver solver,
+                                HYPRE_Int          matmult_type  )
+{
+   return ( hypre_PFMGSetMatmultType( (void *) solver, matmult_type ) );
+}
+
+HYPRE_Int
+HYPRE_StructPFMGGetMatmultType( HYPRE_StructSolver solver,
+                                HYPRE_Int        * matmult_type  )
+{
+   return ( hypre_PFMGGetMatmultType( (void *) solver, matmult_type ) );
+}
+
 /*--------------------------------------------------------------------------
  *--------------------------------------------------------------------------*/
 
