@@ -33,6 +33,9 @@ hypre_PFMG2CreateRAPOp( hypre_StructMatrix *R,
                         hypre_StructGrid   *coarse_grid,
                         HYPRE_Int           cdir        )
 {
+   HYPRE_UNUSED_VAR(R);
+   HYPRE_UNUSED_VAR(P);
+
    hypre_StructMatrix    *RAP;
 
    hypre_Index           *RAP_stencil_shape;
@@ -43,7 +46,7 @@ hypre_PFMG2CreateRAPOp( hypre_StructMatrix *R,
 
    hypre_Index            index_temp;
    HYPRE_Int              j, i;
-   HYPRE_Int              stencil_rank;
+   HYPRE_Int              stencil_entry;
 
    RAP_stencil_dim = 2;
 
@@ -51,7 +54,7 @@ hypre_PFMG2CreateRAPOp( hypre_StructMatrix *R,
     * Define RAP_stencil
     *-----------------------------------------------------------------------*/
 
-   stencil_rank = 0;
+   stencil_entry = 0;
 
    /*-----------------------------------------------------------------------
     * non-symmetric case
@@ -71,11 +74,11 @@ hypre_PFMG2CreateRAPOp( hypre_StructMatrix *R,
          {
 
             /*--------------------------------------------------------------
-             * Storage for 9 elements (c,w,e,n,s,sw,se,nw,se)
+             * Storage for 9 entries (c,w,e,n,s,sw,se,nw,se)
              *--------------------------------------------------------------*/
             hypre_SetIndex3(index_temp, i, j, 0);
-            MapIndex(index_temp, cdir, RAP_stencil_shape[stencil_rank]);
-            stencil_rank++;
+            MapIndex(index_temp, cdir, RAP_stencil_shape[stencil_entry]);
+            stencil_entry++;
          }
       }
    }
@@ -101,13 +104,13 @@ hypre_PFMG2CreateRAPOp( hypre_StructMatrix *R,
          {
 
             /*--------------------------------------------------------------
-             * Store 5 elements in (c,w,s,sw,se)
+             * Store 5 entries in (c,w,s,sw,se)
              *--------------------------------------------------------------*/
-            if ( i + j <= 0 )
+            if (i + j <= 0)
             {
                hypre_SetIndex3(index_temp, i, j, 0);
-               MapIndex(index_temp, cdir, RAP_stencil_shape[stencil_rank]);
-               stencil_rank++;
+               MapIndex(index_temp, cdir, RAP_stencil_shape[stencil_entry]);
+               stencil_entry++;
             }
          }
       }
@@ -129,7 +132,7 @@ hypre_PFMG2CreateRAPOp( hypre_StructMatrix *R,
    /*-----------------------------------------------------------------------
     * Set number of ghost points - one one each boundary
     *-----------------------------------------------------------------------*/
-   hypre_StructMatrixSetNumGhost(RAP, RAP_num_ghost);
+   HYPRE_StructMatrixSetNumGhost(RAP, RAP_num_ghost);
 
    return RAP;
 }
@@ -2462,6 +2465,3 @@ hypre_PFMG2BuildRAPNoSym_onebox_FSS9_CC1(
 
    return hypre_error_flag;
 }
-
-
-
