@@ -26,15 +26,16 @@ EOF
    ;;
 esac
 
-RESET=`shopt -p nullglob`  # Save current nullglob setting
-shopt -s nullglob          # Return an empty string for failed wildcard matches 
+SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
+RESET=`shopt -p nullglob`                # Save current nullglob setting
+shopt -s nullglob                        # Return an empty string for failed wildcard matches
 if [ "x$1" = "x" ]
 then
-   testdirs=`echo TEST*`   # All TEST directories
+   testdirs=`echo ${SCRIPT_DIR}/TEST*`   # All TEST directories
 else
-   testdirs=`echo $*`      # Only the specified test directories
+   testdirs=`echo $*`                    # Only the specified test directories
 fi
-$RESET                     # Restore nullglob setting
+$RESET                                   # Restore nullglob setting
 
 for testdir in $testdirs
 do
