@@ -775,23 +775,6 @@
       end
 
 
-!***********************************************************************
-!     fhypre_structsetrandomvalues
-!***********************************************************************
-      subroutine fhypre_structsetrandomvalues(fvector, fseed)
-      integer ierr
-      integer fseed
-      integer*8 fvector
-
-      call hypre_StructSetRandomValues(fvector, fseed, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsetrandomvalues: err = ', ierr
-      endif
-
-      return
-      end
-
-
 !***********************************************************************
 !     fhypre_structsetupinterpreter
 !***********************************************************************
@@ -2230,299 +2213,3 @@
       return
       end
 
-
-
-
-
-!***********************************************************************
-!             HYPRE_StructSparseMSG routines
-!***********************************************************************
-
-!***********************************************************************
-!     fhypre_structsparsemsgcreate
-!***********************************************************************
-      subroutine fhypre_structsparsemsgcreate(fcomm, fsolver)
-      integer ierr
-      integer fcomm
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGCreate(fcomm, fsolver, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgcreate: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgdestroy
-!***********************************************************************
-      subroutine fhypre_structsparsemsgdestroy(fsolver)
-      integer ierr
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGDestroy(fsolver, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgdestroy: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetup
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetup(fsolver, fA, fb, fx)
-      integer ierr
-      integer*8 fsolver
-      integer*8 fA
-      integer*8 fb
-      integer*8 fx
-
-      call HYPRE_StructSparseMSGSetup(fsolver, fA, fb, fx, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetup: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsolve
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsolve(fsolver, fA, fb, fx)
-      integer ierr
-      integer*8 fsolver
-      integer*8 fA
-      integer*8 fb
-      integer*8 fx
-
-      call HYPRE_StructSparseMSGSolve(fsolver, fA, fb, fx, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsolve: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetjump
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetjump(fsolver, fjump)
-      integer ierr
-      integer fjump
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetJump(fsolver, fjump, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetjump: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsettol
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsettol(fsolver, ftol)
-      integer ierr
-      integer*8 fsolver
-      double precision ftol
-
-      call HYPRE_StructSparseMSGSetTol(fsolver, ftol, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsettol: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetmaxiter
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetmaxite(fsolver, fmaxiter)
-      integer ierr
-      integer fmaxiter
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetMaxIter(fsolver, fmaxiter, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetmaxite: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetrelchange
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetrelcha(fsolver, frelchange)
-      integer ierr
-      integer frelchange
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetRelChan(fsolver, frelchange, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetrelcha: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetzeroguess
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetzerogu(fsolver)
-      integer ierr
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetZeroGue(fsolver, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetzerogu: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetnonzeroguess
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetnonzer(fsolver)
-      integer ierr
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetNonZero(fsolver, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetnonzer: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsggetnumiterations
-!***********************************************************************
-      subroutine fhypre_structsparsemsggetnumite(fsolver, fniters)
-      integer ierr
-      integer fniters
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGGetNumIter(fsolver, fniters, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsggetnumite: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsggetfinalrelativeresidualnorm
-!***********************************************************************
-      subroutine fhypre_structsparsemsggetfinalr(fsolver, fnorm)
-      integer ierr
-      integer*8 fsolver
-      double precision fnorm
-
-      call HYPRE_StructSparseMSGGetFinalRe(fsolver, fnorm, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsggetfinalr: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetrelaxtype
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetrelaxt(fsolver, frelaxtype)
-      integer ierr
-      integer frelaxtype
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetRelaxTy(fsolver, frelaxtype, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetrelaxt: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetnumprerelax
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetnumpre(fsolver, fnprelax)
-      integer ierr
-      integer fnprelax
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetNumPreR(fsolver, fnprelax, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetnumpre: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetnumpostrelax
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetnumpos(fsolver, fnpstrlx)
-      integer ierr
-      integer fnpstrlx
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetNumPost(fsolver, fnpstrlx, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetnumpos: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetnumfinerelax
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetnumfin(fsolver, fnfine)
-      integer ierr
-      integer fnfine
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetNumFine(fsolver, fnfine, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetnumfin: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetlogging
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetloggin(fsolver, flogging)
-      integer ierr
-      integer flogging
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetLogging(fsolver, flogging, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetloggin: err = ', ierr
-      endif
-
-      return
-      end
-
-!***********************************************************************
-!     fhypre_structsparsemsgsetprintlevel
-!***********************************************************************
-      subroutine fhypre_structsparsemsgsetprintl(fsolver, fprntlvl)
-      integer ierr
-      integer fprntlvl
-      integer*8 fsolver
-
-      call HYPRE_StructSparseMSGSetPrintLe(fsolver, fprntlvl, ierr)
-      if (ierr .ne. 0) then
-         print *, 'fhypre_structsparsemsgsetprintl: err = ', ierr
-      endif
-
-      return
-      end
