@@ -4,7 +4,6 @@
 #
 # SPDX-License-Identifier: (Apache-2.0 OR MIT)
 
-
 # global variables
 BatchMode=0
 NoRun=0
@@ -19,7 +18,7 @@ TestDirNames=""            # string of names of TEST_* directories used
 HOST=`hostname`
 NumThreads=0               # number of OpenMP threads to use if > 0
 Valgrind=""                # string to add to MpirunString when using valgrind
-cudamemcheck=""            # string to add to MpirunString when using cudamemcheck
+gpumemcheck=""             # string to add to MpirunString when using GPU memory checker
 mpibind=""                 # string to add to MpirunString when using mpibind
 script=""                  # string to add to MpirunString when using script
 SaveExt="saved"            # saved file extension
@@ -44,6 +43,7 @@ function usage
    printf "    -save <ext>    use '<test>.saved.<ext> for the saved-file extension\n"
    printf "    -valgrind      use valgrind memory checker\n"
    printf "    -cudamemcheck  use CUDA memory checker\n"
+   printf "    -cudasan       use CUDA compute sanitizer\n"
    printf "    -mpibind       use mpibind\n"
    printf "    -script <sh>   use a script before the command\n"
    printf "    -n|-norun      turn off execute mode, echo what would be run\n"
@@ -118,18 +118,14 @@ function MpirunString
          shift
          RunString="srun -n$1"
          ;;
-      rzansel*)
-         shift
-         RunString="lrun -T$1"
-         ;;
-      lassen*)
-         shift
-         RunString="lrun -n$1"
-         ;;
       tioga*)
          shift
          RunString="srun -n$1"
          ;;
+      matrix*)
+         shift
+         RunString="srun -n$1 --time=1 --overlap"
+         ;;
       node*)
          shift
          RunString="srun -n$1"
@@ -146,7 +142,7 @@ function MpirunString
    NumArgs2=$(($#+1))
    if [ "$NumArgs1" -eq "$NumArgs2" ] ; then
       shift
-      RunString="$RunString $script $mpibind $cudamemcheck $Valgrind $*"
+      RunString="$RunString $script $mpibind $gpumemcheck $Valgrind $*"
       #echo $RunString
    fi
 }
@@ -522,15 +518,19 @@ do
          ;;
       -valgrind)
          shift
-         Valgrind="valgrind -q --suppressions=`pwd`/runtest.valgrind --track-origins=yes --leak-check=full --show-leak-kinds=all"
+         Valgrind="valgrind -q --suppressions=`pwd`/runtest.valgrind --leak-check=full --track-origins=yes --show-reachable=yes"
          ;;
       -cudamemcheck)
          shift
-         cudamemcheck="cuda-memcheck --leak-check full"
+         gpumemcheck="cuda-memcheck --leak-check full"
+         ;;
+      -cudasan)
+         shift
+         gpumemcheck="compute-sanitizer"
          ;;
       -mpibind)
          shift
-         mpibind="mpibind"
+         mpibind="--mpibind=verbose:1"
          ;;
       -script)
          shift
@@ -608,7 +608,6 @@ CleanUp $TestDirNames $ExecFileNames
 cat > runtest.filters <<EOF
 PMIX ERROR: PMIX_ERR_NOT_FOUND in file dstore_base.c at line 1567
 PMIX ERROR: PMIX_ERROR in file dstore_base.c at line 2334
-lrun warning: default mapping forced to idle
 srun: Warning: can't run 1 processes on 2 nodes, setting nnodes to 1
 hypre_MPI_Init
 job [0-9]* queued and waiting for resources
