@@ -60,9 +60,7 @@ using hypre_DeviceItem = void*;
 
 #if CUDA_VERSION >= 11000
 #define THRUST_IGNORE_DEPRECATED_CPP11
-#define CUB_IGNORE_DEPRECATED_CPP11
 #define THRUST_IGNORE_DEPRECATED_CPP_DIALECT
-#define CUB_IGNORE_DEPRECATED_CPP_DIALECT
 #endif
 
 #ifndef CUSPARSE_VERSION
@@ -119,25 +117,41 @@ using hypre_DeviceItem = void*;
 // Macro for device memory prefetching (CUDART 13.0+)
 #define HYPRE_MEM_PREFETCH_DEVICE(ptr, size, stream) \
    do { \
-      cudaMemLocation loc = {cudaMemLocationTypeDevice, hypre_HandleDevice(hypre_handle())}; \
-      HYPRE_CUDA_CALL(cudaMemPrefetchAsync(ptr, size, loc, 0, stream)); \
+      if (hypre_HandleDeviceUVM(hypre_handle())) \
+      { \
+         cudaMemLocation loc = {cudaMemLocationTypeDevice, hypre_HandleDevice(hypre_handle())}; \
+         HYPRE_CUDA_CALL(cudaMemPrefetchAsync(ptr, size, loc, 0, stream)); \
+      } \
    } while (0)
 
 // Macro for host memory prefetching (CUDART 13.0+)
 #define HYPRE_MEM_PREFETCH_HOST(ptr, size, stream) \
    do { \
-      cudaMemLocation loc = {cudaMemLocationTypeHost, cudaCpuDeviceId}; \
-      HYPRE_CUDA_CALL(cudaMemPrefetchAsync(ptr, size, loc, 0, stream)); \
+      if (hypre_HandleDeviceUVM(hypre_handle())) \
+      { \
+         cudaMemLocation loc = {cudaMemLocationTypeHost, cudaCpuDeviceId}; \
+         HYPRE_CUDA_CALL(cudaMemPrefetchAsync(ptr, size, loc, 0, stream)); \
+      } \
    } while (0)
 
 #else
 // Macro for device memory prefetching (< CUDART 13.0)
 #define HYPRE_MEM_PREFETCH_DEVICE(ptr, size, stream) \
-   HYPRE_CUDA_CALL(cudaMemPrefetchAsync(ptr, size, hypre_HandleDevice(hypre_handle()), stream))
+   do { \
+      if (hypre_HandleDeviceUVM(hypre_handle())) \
+      { \
+         HYPRE_CUDA_CALL(cudaMemPrefetchAsync(ptr, size, hypre_HandleDevice(hypre_handle()), stream)); \
+      } \
+   } while (0)
 
 // Macro for host memory prefetching (< CUDART 13.0)
 #define HYPRE_MEM_PREFETCH_HOST(ptr, size, stream) \
-   HYPRE_CUDA_CALL(cudaMemPrefetchAsync(ptr, size, cudaCpuDeviceId, stream))
+   do { \
+      if (hypre_HandleDeviceUVM(hypre_handle())) \
+      { \
+         HYPRE_CUDA_CALL(cudaMemPrefetchAsync(ptr, size, cudaCpuDeviceId, stream)); \
+      } \
+   } while (0)
 #endif
 
 #endif /* defined(HYPRE_USING_CUDA) */
@@ -207,7 +221,7 @@ using hypre_DeviceItem = void*;
 #include <thrust/version.h>
 
 /* VPM: this is needed to support cuda 10. not_fn is the correct replacement going forward. */
-#define THRUST_VERSION_NOTFN 200700
+#define THRUST_VERSION_NOTFN 200600
 #if (defined(THRUST_VERSION) && THRUST_VERSION < THRUST_VERSION_NOTFN)
 #define HYPRE_THRUST_NOT(pred) thrust::not1(pred)
 #else
@@ -258,14 +272,20 @@ using hypre_DeviceItem = sycl::nd_item<3>;
  *      device defined values
  * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-#if HYPRE_WARP_SIZE == 32
-#define HYPRE_WARP_BITSHIFT      5
-#define HYPRE_WARP_FULL_MASK     0xFFFFFFFF
-
-#elif HYPRE_WARP_SIZE == 64
+#if HYPRE_WARP_SIZE == 64
 #define HYPRE_WARP_BITSHIFT      6
 #define HYPRE_WARP_FULL_MASK     0xFFFFFFFFFFFFFFFF
 
+#elif HYPRE_WARP_SIZE == 32
+#define HYPRE_WARP_BITSHIFT      5
+
+/* HIP 6.5 onwards requires masks to be 64-bit integers even when compiling for warp size 32 */
+#if defined(HYPRE_USING_HIP) && HIP_VERSION > 60500000 && !defined(HIP_DISABLE_WARP_SYNC_BUILTINS)
+#define HYPRE_WARP_FULL_MASK     0xFFFFFFFFFFFFFFFF
+#else
+#define HYPRE_WARP_FULL_MASK     0xFFFFFFFF
+#endif
+
 #else
 #error "Unsupported value for HYPRE_WARP_SIZE"
 #endif
@@ -713,9 +733,6 @@ using hypre_DeviceItem = sycl::nd_item<3>;
  *      device info data structures
  * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-struct hypre_cub_CachingDeviceAllocator;
-typedef struct hypre_cub_CachingDeviceAllocator hypre_cub_CachingDeviceAllocator;
-
 #if defined(HYPRE_USING_CUSOLVER)
 typedef cusolverDnHandle_t vendorSolverHandle_t;
 #elif defined(HYPRE_USING_ROCSOLVER)
@@ -759,15 +776,6 @@ struct hypre_DeviceData
 #endif
 #endif
 
-#if defined(HYPRE_USING_DEVICE_POOL)
-   hypre_uint                        cub_bin_growth;
-   hypre_uint                        cub_min_bin;
-   hypre_uint                        cub_max_bin;
-   size_t                            cub_max_cached_bytes;
-   hypre_cub_CachingDeviceAllocator *cub_dev_allocator;
-   hypre_cub_CachingDeviceAllocator *cub_uvm_allocator;
-#endif
-
 #if defined(HYPRE_USING_CUDA) || defined(HYPRE_USING_HIP)
    hypre_device_allocator            device_allocator;
 #endif
@@ -776,7 +784,10 @@ struct hypre_DeviceData
    HYPRE_Int                         device_max_work_group_size;
 #else
    HYPRE_Int                         device;
+   HYPRE_Int                         device_uvm;
 #endif
+   HYPRE_Int                         use_gpu_aware_mpi;
+   HYPRE_Int                         gs_method; /* device G-S options */
    hypre_int                         device_max_shmem_per_block[3];
    /* by default, hypre puts GPU computations in this stream
     * Do not be confused with the default (null) stream */
@@ -804,14 +815,11 @@ struct hypre_DeviceData
    HYPRE_Int                         use_gpu_rand;
 };
 
-#define hypre_DeviceDataCubBinGrowth(data)                   ((data) -> cub_bin_growth)
-#define hypre_DeviceDataCubMinBin(data)                      ((data) -> cub_min_bin)
-#define hypre_DeviceDataCubMaxBin(data)                      ((data) -> cub_max_bin)
-#define hypre_DeviceDataCubMaxCachedBytes(data)              ((data) -> cub_max_cached_bytes)
-#define hypre_DeviceDataCubDevAllocator(data)                ((data) -> cub_dev_allocator)
-#define hypre_DeviceDataCubUvmAllocator(data)                ((data) -> cub_uvm_allocator)
 #define hypre_DeviceDataDevice(data)                         ((data) -> device)
+#define hypre_DeviceDataDeviceUVM(data)                      ((data) -> device_uvm)
 #define hypre_DeviceDataDeviceMaxWorkGroupSize(data)         ((data) -> device_max_work_group_size)
+#define hypre_DeviceDataUseGpuAwareMPI(data)                 ((data) -> use_gpu_aware_mpi)
+#define hypre_DeviceDataGSMethod(data)                       ((data) -> gs_method)
 #define hypre_DeviceDataDeviceMaxShmemPerBlock(data)         ((data) -> device_max_shmem_per_block)
 #define hypre_DeviceDataDeviceMaxShmemPerBlockInited(data)  (((data) -> device_max_shmem_per_block)[2])
 #define hypre_DeviceDataComputeStreamNum(data)               ((data) -> compute_stream_num)
@@ -1221,8 +1229,8 @@ void hypre_gpu_atomicAdd(hypre_int pos, T* address, T val)
    atomicAdd((T*)(address + pos), val);
 }
 
-// There are no *_sync functions in HIP
-#if defined(HYPRE_USING_HIP) || (CUDA_VERSION < 9000)
+// There are no *_sync functions in HIP < 6.5
+#if (defined(HYPRE_USING_HIP) && HIP_VERSION < 60500000 || defined(HIP_DISABLE_WARP_SYNC_BUILTINS))
 
 template <typename T>
 static __device__ __forceinline__
@@ -1265,14 +1273,23 @@ void __syncwarp()
 {
 }
 
-#endif // #if defined(HYPRE_USING_HIP) || (CUDA_VERSION < 9000)
+static __device__ __forceinline__
+hypre_int __any_sync(unsigned mask, hypre_int predicate)
+{
+   HYPRE_UNUSED_VAR(mask);
+
+   return __any(predicate);
+}
+
+#endif // if (defined(HYPRE_USING_HIP) && HIP_VERSION < 60500000)
 
 static __device__ __forceinline__
 hypre_mask hypre_ballot_sync(hypre_DeviceItem &item, hypre_mask mask, hypre_int predicate)
 {
+#if defined(HYPRE_USING_CUDA) ||\
+  (defined(HYPRE_USING_HIP) && HIP_VERSION >= 60500000 && !defined(HIP_DISABLE_WARP_SYNC_BUILTINS))
    HYPRE_UNUSED_VAR(item);
 
-#if defined(HYPRE_USING_CUDA)
    return __ballot_sync(mask, predicate);
 #else
    HYPRE_UNUSED_VAR(mask);
@@ -1300,16 +1317,6 @@ HYPRE_Int hypre_ffs(hypre_mask mask)
 #endif
 }
 
-#if defined(HYPRE_USING_HIP)
-static __device__ __forceinline__
-hypre_int __any_sync(unsigned mask, hypre_int predicate)
-{
-   HYPRE_UNUSED_VAR(mask);
-
-   return __any(predicate);
-}
-#endif
-
 /* sync the thread block */
 static __device__ __forceinline__
 void block_sync(hypre_DeviceItem &item)
@@ -1926,12 +1933,14 @@ HYPRE_Int hypre_popc(hypre_mask mask)
 static __device__ __forceinline__
 HYPRE_Int hypre_ffs(hypre_mask mask)
 {
-   return (HYPRE_Int)dpct::ffs<HYPRE_Int>(mask);
+   return (HYPRE_Int) dpct::ffs<HYPRE_Int>(mask);
 }
 
 static __device__ __forceinline__
 hypre_int warp_any_sync(hypre_DeviceItem &item, hypre_mask mask, hypre_int predicate)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    return sycl::any_of_group(item.get_sub_group(), predicate);
 }
 
@@ -1939,6 +1948,8 @@ template <typename T>
 static __device__ __forceinline__
 T warp_shuffle_sync(hypre_DeviceItem &item, hypre_mask mask, T val, hypre_int src_line)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    return sycl::group_broadcast(item.get_sub_group(), val, src_line);
 }
 
@@ -1947,6 +1958,8 @@ static __device__ __forceinline__
 T warp_shuffle_sync(hypre_DeviceItem &item, hypre_mask mask, T val, hypre_int src_line,
                     hypre_int width)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    hypre_int lane_id = hypre_gpu_get_lane_id<1>(item);
    hypre_int group_start = (lane_id / width) * width;
    hypre_int src_in_warp = group_start + (src_line % width);
@@ -1957,6 +1970,8 @@ template <typename T>
 static __device__ __forceinline__
 T warp_shuffle_up_sync(hypre_DeviceItem &item, hypre_mask mask, T val, hypre_uint delta)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    return sycl::shift_group_right(item.get_sub_group(), val, delta);
 }
 
@@ -1965,6 +1980,8 @@ static __device__ __forceinline__
 T warp_shuffle_up_sync(hypre_DeviceItem &item, hypre_mask mask, T val, hypre_uint delta,
                        hypre_int width)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    hypre_int lane_id = hypre_gpu_get_lane_id<1>(item);
    hypre_int group_start = (lane_id / width) * width;
    hypre_int src_in_warp = lane_id - delta >= group_start ? lane_id - delta : lane_id;
@@ -1975,6 +1992,8 @@ template <typename T>
 static __device__ __forceinline__
 T warp_shuffle_down_sync(hypre_DeviceItem &item, hypre_mask mask, T val, hypre_uint delta)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    return sycl::shift_group_left(item.get_sub_group(), val, delta);
 }
 
@@ -1983,6 +2002,8 @@ static __device__ __forceinline__
 T warp_shuffle_down_sync(hypre_DeviceItem &item, hypre_mask mask, T val, hypre_uint delta,
                          hypre_int width)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    hypre_int lane_id = hypre_gpu_get_lane_id<1>(item);
    hypre_int group_end = ((lane_id / width) + 1) * width - 1;
    hypre_int src_in_warp = lane_id + delta <= group_end ? lane_id + delta : lane_id;
@@ -1993,6 +2014,8 @@ template <typename T>
 static __device__ __forceinline__
 T warp_shuffle_xor_sync(hypre_DeviceItem &item, hypre_mask mask, T val, hypre_int lane_mask)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    return sycl::permute_group_by_xor(item.get_sub_group(), val, lane_mask);
 }
 
@@ -2001,6 +2024,8 @@ static __device__ __forceinline__
 T warp_shuffle_xor_sync(hypre_DeviceItem &item, hypre_mask mask, T val, hypre_int lane_mask,
                         hypre_int width)
 {
+   HYPRE_UNUSED_VAR(mask);
+
    hypre_int lane_id = hypre_gpu_get_lane_id<1>(item);
    hypre_int group_end = ((lane_id / width) + 1) * width - 1;
    hypre_int src_in_warp = lane_id ^ lane_mask;
@@ -2236,26 +2261,6 @@ HYPRE_Int hypreDevice_CsrRowPtrsToIndicesWithRowNum(HYPRE_Int nrows, HYPRE_Int n
 
 #endif
 
-#if defined(HYPRE_USING_CUDA) || defined(HYPRE_USING_HIP)
-
-#if defined(HYPRE_USING_CUDA)
-cudaError_t hypre_CachingMallocDevice(void **ptr, size_t nbytes);
-
-cudaError_t hypre_CachingMallocManaged(void **ptr, size_t nbytes);
-
-cudaError_t hypre_CachingFreeDevice(void *ptr);
-
-cudaError_t hypre_CachingFreeManaged(void *ptr);
-#endif
-
-hypre_cub_CachingDeviceAllocator * hypre_DeviceDataCubCachingAllocatorCreate(hypre_uint bin_growth,
-                                                                             hypre_uint min_bin, hypre_uint max_bin, size_t max_cached_bytes, bool skip_cleanup, bool debug,
-                                                                             bool use_managed_memory);
-
-void hypre_DeviceDataCubCachingAllocatorDestroy(hypre_DeviceData *data);
-
-#endif // #if defined(HYPRE_USING_CUDA) || defined(HYPRE_USING_HIP)
-
 #if defined(HYPRE_USING_CUSPARSE)
 
 cudaDataType hypre_HYPREComplexToCudaDataType();
