@@ -88,11 +88,7 @@ typedef struct
 
 } hypre_TimingType;
 
-#ifdef HYPRE_TIMING_GLOBALS
-hypre_TimingType *hypre_global_timing = NULL;
-#else
 extern hypre_TimingType *hypre_global_timing;
-#endif
 
 /*-------------------------------------------------------
  * Accessor functions
